{ pkgs, lib, config, ... }:
{
  config = lib.mkIf config.services.icecast.enable {
    services.liquidsoap.streams = lib.mkIf config.services.icecast.enable {
      jimscrapped = pkgs.writeText "jimscrapped" ''
        settings.log.stdout.set(true)
        settings.init.allow_root.set(true)
        settings.scheduler.fast_queues.set(2)
        
        jimscrapped = mksafe(playlist(mode='randomize', reload=1, reload_mode="rounds", "/export/JimboNFS/Music/JimScrapped"))
        jimscrapped_fallback = fallback([jimscrapped, jimscrapped])
        
        output.icecast(
          %ffmpeg(format="ogg", %audio(codec="libvorbis", samplerate=48000, b="256k", channels=2)),
          host="127.0.0.1",
          port=265,
          password="${config.secrets.castSourcePass}",
          encoding = "UTF-8",

          name="Jimbo's Scrap",
          genre="Scrapped",
          description="Music canned from the main radio.",
          mount="jimscrapped.opus",
          icy_metadata=["artist", "title"],
          public=true,

          jimscrapped_fallback
        )
      '';
    };

    # Avoid the most stupid error imaginable
    systemd.services.jimscrapped = {
      after = [ "network-online.target" ];
      wants = [ "network-online.target" ];
    };
  };
}
